(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{35:function(e,t,a){e.exports=a(52)},52:function(e,t,a){"use strict";a.r(t);var n=a(15),r=a.n(n),c=a(32),s=a.n(c),l=a(0),o=a(1),i=a(2),u=a(3),d=a(27),m=(a(42),a(51),null),p=function(e){Object(i.a)(a,e);var t=Object(u.a)(a);function a(e){var n;return Object(o.a)(this,a),(n=t.call(this,e)).state={numClicks:0,isFocused:!1},n.render=function(){var e=n.props.theme,t={};if(e){var a="1px solid ".concat(n.state.isFocused?e.primaryColor:"gray");t.border=a,t.outline=a}return r.a.createElement("div",{className:"event-section",id:"style"},r.a.createElement("div",null,r.a.createElement("div",{className:"header-container  scrollbar",id:"style"},n.events.map((function(e,t){return r.a.createElement("div",{className:m===t?"selected header":"header",onClick:function(e){e.preventDefault(),n.onSelected(t)}},r.a.createElement("p",null,e.header),m===t?r.a.createElement("div",{className:"sub-headers-div"},r.a.createElement("p",null,n.events[m].subheader)):"")}))),r.a.createElement("div",{className:"sub-header-container"})))},n.onSelected=function(e){m=e,n.setState({selectedEvent:e}),n.setState((function(){return d.a.setComponentValue({start_char:n.events[m].start_char,end_char:n.events[m].end_char})}))},n.inputRef=r.a.createRef(),n.startRef=r.a.createRef(),n.events=n.props.args.event.events,n}return Object(l.a)(a)}(d.b),v=Object(d.c)(p);s.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(v,null)),document.getElementById("root"))}},[[35,1,2]]]);
//# sourceMappingURL=main.c5e881ee.chunk.js.map